import { TransactionalMessage } from '../../message/transactional-message';
import { ReplicationConcurrencyController } from './concurrency-controller';
export type ReplicationMultiConcurrencyType = 'mutex' | 'semaphore' | 'full-concurrency' | 'discriminating-mutex';
/**
 * Use different mutex controllers depending on the desired concurrency level
 * for different messages. If a discriminating mutex should be used, the
 * discriminator function must be supplied as well. If a semaphore concurrency
 * controller should be used, the `maxSemaphoreParallelism` should be set (it
 * defaults to 5);
 * @param getConcurrencyType Implements the logic which concurrency controller should be used e.g. based on the aggregate and message type
 * @param discriminator The discriminator to find or create a mutex for when using the discriminating mutex.
 * @returns The controller to acquire and release the mutex for a specific discriminator
 */
export declare const createReplicationMultiConcurrencyController: (getConcurrencyType: (message: TransactionalMessage) => ReplicationMultiConcurrencyType, settings?: {
    discriminator?: ((message: TransactionalMessage) => string) | undefined;
    maxSemaphoreParallelism?: number | undefined;
} | undefined) => ReplicationConcurrencyController;
//# sourceMappingURL=create-multi-concurrency-controller.d.ts.map