"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createReplicationSemaphoreConcurrencyController = void 0;
const async_mutex_1 = require("async-mutex");
/**
 * Uses a semaphore to execute up to a given amount of messages in parallel. Any
 * additional message waits until a currently processed message finishes.
 * @returns The controller to acquire and release the semaphore and to cancel all semaphores
 */
const createReplicationSemaphoreConcurrencyController = (maxParallel) => {
    const semaphore = new async_mutex_1.Semaphore(maxParallel);
    return {
        acquire: () => __awaiter(void 0, void 0, void 0, function* () {
            // eslint-disable-next-line @typescript-eslint/no-unused-vars
            const [_, release] = yield semaphore.acquire();
            return release;
        }),
        cancel: semaphore.cancel.bind(semaphore),
    };
};
exports.createReplicationSemaphoreConcurrencyController = createReplicationSemaphoreConcurrencyController;
//# sourceMappingURL=create-semaphore-concurrency-controller.js.map